<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Van élet a böngészőn kívül!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Verzió: %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licensz tulajdonosa: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>A %1 egy ingyenes szoftver, de a fejlesztése értékes időt emészt fel.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>&lt;a href=&apos;%1&apos;&gt;Adakozással&lt;/a&gt; támogassa a %2 program folyamatos fejlesztését.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Fordítsa le a %1 programot az anyanyelvére a következővel: %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation>%1 támogatásával</translation>
    </message>
    <message>
        <source>Open-source software</source>
        <translation>Nyílt forráskódú szoftver</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ikon tervezője: %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>A &lt;a href=&apos;%1&apos;&gt;GNU General Public licenccel&lt;/a&gt; megjelentetve</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Bezárás</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Névjegy</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Liszenszadatok megadása</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Email:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Kód</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Szerezzen licencet a %1 programhoz</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>A teljes verzió lehetőséget nyújt a videók megszakítás nélküli lejátszására.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>A teljes verzió megvásárlásával a %1 programba fektetett munkámat is támogatja.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Demó használata</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Liszensz megadása</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Liszensz megvásárlása</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Letöltés</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>%1 által</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation><numerusform>%n új videód van</numerusform><numerusform>%n új videód van</numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Összes videó</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Megnézetlen videók</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Utoljára frissítve</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Utoljára hozzáadva</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Utoljára megnézve</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Legtöbbször megnézett</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Rendezés</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Mind megjelölése megnézettként</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Frissítések mutatása</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Nincsenek feliratkozások. A csillag szimbólumot kell használni a csatornákra való feliratkozáshoz.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Összes videó</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Megnézetlen videók</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Megjelölés megnézettként</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Leiratkozás</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Nincs frissítés a feliratkozott csatornákon.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Épp most</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation>K</translation>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation>M</translation>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 néző</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bájt</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bájt/mp</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/mp</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/mp</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>másodperc</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>perc</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>Hátralévő idő: %4 %5</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 letöltve ide: %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Letöltés befejezve</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Hely módosítása...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Letöltés helyének kiválasztása</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>A letöltés helye megváltozott.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>A folyamatban lévő letöltések még a régebbi helyre kerülnek.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Letöltés ide: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Letöltések</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>A futtatandó fájl módosítva lett, lehetséges hogy egy vírus által.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 nem fog futni. Próbáld újratelepíteni.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Újratelepítés</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Lejátszás</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Megállítás</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Lejátszás/megállítás</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Leállítás</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Lejátszás befejezése az aktuális szám után</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Következő szám</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Előző szám</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Hangerő növelése</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Hangerő csökkentése</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Némítás</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Ugrás előre</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Ugrás vissza</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Videók és csatornák keresése kulcsszó alapján</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Videók keresése kategória szerint</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Feliratkozások</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Csatorna-feliratkozások</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Helyezze kényelembe magát</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ablak</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimalizálás</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Leállítás</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Lejátszás befejezése és visszatérés a keresés nézetre</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>&amp;Előző</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Ugrás az előző számra</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>U&amp;grás</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Ugrás a következő videóra</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Lejátszás</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Lejátszás folytatása</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Teljes képernyő</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Teljes képernyőre váltás</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>&amp;Kompaktmód</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Lejátszási lista és eszközsor elrejtése</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>&amp;YouTube oldal megnyitása</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Ugrás a YouTube videó oldalára és a lejátszás megállítása</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>YouTube &amp;hivatkozás másolása</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Az aktuális videó Youtube &amp;hivatkozásának másolása a vágólapra</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>&amp;Videó-URL másolása</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Az aktuális videó adatfolyam URL címének másolása a vágólapra</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>További videó&amp;részletek keresése</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>További videórészletek keresése remélhetőleg helyes sorrendben</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Eltávolítás</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Kijelölt videók eltávolítása a lejátszási listáról</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mozgatás &amp;felfelé</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Kijelölt videók mozgatása felfelé a lejátszási listában</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mozgatás &amp;lefelé</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Kijelölt videók mozgatása lefelé a lejátszási listában</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>&amp;Legutóbbi keresések törlése</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Keresési előzmények törlése. Nem vonható vissza.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Kilépés</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Viszlát</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Webhely</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 a weben</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>&amp;Támogasd</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Támogassa a %1 program folyamatos fejlesztését</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Névjegy</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Információ a %1 programról</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Hangerő némítása</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>&amp;Manuális lejátszás</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Videók lejátszása manuális indítással</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Letöltések</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>A videóletöltések részleteinek megjelenítése</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Letöltés</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Aktuális videó letöltése</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>&amp;Snapshot készítése</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Subscribe a csatornára</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Aktuális videó megosztása a következővel: %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Email</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Bezárás</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Többi ablak fölött</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>&amp;Videó után leállítás</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Hiba bejelentése</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Keresés pontosítása</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Továbbiak...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;Kapcsolódó videók</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>A jelenlegihez kapcsolódó videók megtekintése</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Megtekintés a következővel:</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>Korlátozott mód</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>Esetleg nem megfelelő tartalmú videók elrejtése</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation>Toggle &amp;Menu Bar</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menü</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Love %1? Értékeld!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>%1 megvásárlása...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Alkalmazás</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Lejátszás</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>&amp;Lejátszási lista</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Videó</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Megosztás</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Megtekintés</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Súgó</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Hangerő növelése: %1, hangerő csökkentése: %2</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Válaszd ki a jelenlegi tartózkodási helyed</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>%1 megnyitása</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Szeretne kilépni a %1 programból letöltés közben?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Ha bezárja a %1 programot, a letöltés megszakad.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Bezárás és letöltés megszakítása</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>A letöltés befejeződésének megvárása</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Hiba: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Megállítás</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Lejátszás megállítása</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Betöltés</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Kilépés a &amp;teljes képernyős módból</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Hátralévő idő: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Hangerő: %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Hangerő némítva</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Hangerő némítása feloldva</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Videók maximális felbontásának beállítása: %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>A személyes adatok most már biztonságban vannak</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>A letöltések befejeződtek</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation>A menüt az ALT gomb lenyomásával továbbra is eléred</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>A YouTube hivatkozás most már beilleszthető egy másik alkalmazásba</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Most már beillesztheti a videó adatfolyam URL címét egy másik alkalmazásba</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>A hivatkozás csak korlátozott ideig lesz érvényben.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Letöltés: %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation> - </translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>rész</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>epizód</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>A %1 programból küldve</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Leiratkozás az alábbi csatornáról: %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Feliratkozás az alábbi csatornára: %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation>Ide váltás: %1</translation>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Leiratkozva %1-ról/ről.</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Feliratkozva %1-ra</translation>
    </message>
    <message>
        <source>Rewind %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fast forward %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>channel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>%1 új verziója elérhető!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>A %1 program %2 verziója elérhető. Neked %3 van.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Szeretné letölteni most?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Verzió átugrása</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Emlékeztessen később</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Frissítés telepitése</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Beillesztés</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation>Válassz videót</translation>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 %2 közül (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Előkészítés</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Sikeres befejezés</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Leállítva</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Letöltés leállítása </translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Megjelenítés a következőben: %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Szülőmappa megnyitása</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Letöltés újraindítása </translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>További %1 elem megjelenítése</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Nincsenek videók</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Nincs több videó </translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Rendezés</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Relevancia</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Megtekintések száma</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Értékelés</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Bármikor</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Ma</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 napja</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 napja</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Időtartam</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Összes</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Rövid</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Közepes</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Hosszú</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Rövidebb, mint 4 perc</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>4 perc és 20 perc között</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Hosszabb, mint 20 perc</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Minőség</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Kész</translation>
    </message>
    <message>
        <source>This year</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>4K</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HDR</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Kész</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Keresés</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Üdvözli a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt; program,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>a videók megtekintéséhez.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>egy kulcsszót</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Írjon be</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Legutóbbi kulcsszavak</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Legutóbbi csatornák</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Teljes verzió beszerzése</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Need a remote control for %1? Try %2!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>I keep improving %1 to make it the best I can. Support this work!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>An update is ready to be installed. Quit and install update.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Vissza</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Előre</translation>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Tovább a %1-re</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Vissza a %1-re</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Keresés finomítása</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Így értette: %1?</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Hely módosítása...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Pillanatkép mentve a %1 helyre</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>A pillanatképek mentési helye megváltozott.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Legnépszerübb</translation>
    </message>
    <message>
        <source>Trending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>News</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Movies</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gaming</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Frissítés letöltése...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Letöltés %1...</translation>
    </message>
</context>
<context>
    <name>Updater</name>
    <message>
        <source>Check for Updates...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 is available...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading version %1...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Restart to Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 download failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check for Updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Download Update</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading update...</source>
        <translation>Frissítés letöltése...</translation>
    </message>
    <message>
        <source>Retry Update Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have the latest version.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1 is available.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>An update has been downloaded and is ready to be installed.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>YTJSVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Nem található videó adatfolyam a következőhöz: %1</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Algéria</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentína </translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Ausztrália</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Belgium</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brazília </translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Kanada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Kolumbia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Cseh Köztársaság</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Egyiptom</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Franciaország</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Németország</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghána</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Görögország</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Magyarország</translation>
    </message>
    <message>
        <source>India</source>
        <translation>India</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonézia</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Írország</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Izrael </translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Olaszország</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japán</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordánia</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenya</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malájzia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Mexikó </translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Marokkó</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Hollandia</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Új Zéland</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigéria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Fülöp-szigetek</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Lengyelország</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Oroszország</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Szaúd-Arábia</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Szingapúr</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Dél Afrika</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Dél Korea</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Spanyolország</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Svédország</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Tajvan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunézia</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Törökország</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Egyesült Arab Emirségek</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Nagy Britannia</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Jemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Világszerte</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Nem található videó adatfolyam a következőhöz: %1</translation>
    </message>
</context>
<context>
    <name>updater::DefaultUpdater</name>
    <message>
        <source>There are currently no updates available.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>updater::Dialog</name>
    <message>
        <source>You already have the latest version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading %1 %2...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>%1 új verziója elérhető!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>A %1 program %2 verziója elérhető. Neked %3 van.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Szeretné letölteni most?</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Emlékeztessen később</translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>